;; Generated package description from tramp-hlo.el  -*- no-byte-compile: t -*-
(define-package "tramp-hlo" "0.0.2.0.20251217.141452" "High level operations as Tramp handlers" '((tramp "2.8.0.5")) :commit "02c128d41c1ef7785d6223cee3dbbe224eae4284" :authors '(("Joe Sadusk" . "joe@sadusk.com")) :maintainer '("Joe Sadusk" . "joe@sadusk.com") :url "https://github.com/jsadusk/tramp-hlo")
